import numpy as np

def linear(Z):
    """
    Compute the linear activation function.

    Args:
        Z (numpy.ndarray): The input array.

    Returns:
        numpy.ndarray: The input array Z, unchanged.

    Example:
        ```python
        Z = np.array([[1, 2], [3, 4]])
        A = linear(Z)
        print(A)
        ```
    """
    return Z
